@@ -18,7 +18,7 @@ open Pltac
 
 
 
-let __coq_plugin_name = "funind_plugin"
+let __coq_plugin_name = "coq-core.plugins.funind"
 let _ = Mltop.add_known_module __coq_plugin_name
 
 # 31 "plugins/funind/g_indfun.mlg"
