@@ -14,7 +14,7 @@ open Logic
 
 
 
-let __coq_plugin_name = "ltac_plugin"
+let __coq_plugin_name = "coq-core.plugins.ltac"
 let _ = Mltop.add_known_module __coq_plugin_name
 let () = Tacentries.tactic_extend __coq_plugin_name "reflexivity" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("reflexivity", Tacentries.TyNil), 
@@ -678,11 +678,11 @@ let initial_atomic () =
         "fresh", CAst.make @@ TacArg(TacFreshId [])
       ]
 
-let () = Mltop.declare_cache_obj initial_atomic "ltac_plugin"
+let () = Mltop.declare_cache_obj initial_atomic "coq-core.plugins.ltac"
 
 (* First-class Ltac access to primitive blocks *)
 
-let initial_name s = { mltac_plugin = "ltac_plugin"; mltac_tactic = s; }
+let initial_name s = { mltac_plugin = "coq-core.plugins.ltac"; mltac_tactic = s; }
 let initial_entry s = { mltac_name = initial_name s; mltac_index = 0; }
 
 let register_list_tactical name f =
@@ -712,7 +712,7 @@ let initial_tacticals () =
         ([Name (idn 0)], CAst.make (TacML (initial_entry "solve", [varn 0]))));
   ]
 
-let () = Mltop.declare_cache_obj initial_tacticals "ltac_plugin"
+let () = Mltop.declare_cache_obj initial_tacticals "coq-core.plugins.ltac"
 
 
 
