@@ -11,7 +11,7 @@ open Hints
 
 
 
-let __coq_plugin_name = "ltac_plugin"
+let __coq_plugin_name = "coq-core.plugins.ltac"
 let _ = Mltop.add_known_module __coq_plugin_name
 let () = Tacentries.tactic_extend __coq_plugin_name "eassumption" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("eassumption", Tacentries.TyNil), 
@@ -100,8 +100,9 @@ let _ = (wit_hintbases, hintbases)
  
 
 let eval_uconstrs ist cs =
-  let flags = {
-    Pretyping.use_typeclasses = Pretyping.NoUseTC;
+  let flags = Pretyping.{
+    use_coercions = true;
+    use_typeclasses = NoUseTC;
     solve_unification_constraints = true;
     fail_evar = false;
     expand_evars = true;
@@ -125,7 +126,7 @@ let (wit_auto_using, auto_using) = Tacentries.argument_extend ~name:"auto_using"
                                                             [(Pcoq.Production.make
                                                               (Pcoq.Rule.stop)
                                                               (fun loc -> 
-# 77 "plugins/ltac/g_auto.mlg"
+# 78 "plugins/ltac/g_auto.mlg"
            [] 
                                                                     ));
                                                             (Pcoq.Production.make
@@ -145,7 +146,7 @@ let (wit_auto_using, auto_using) = Tacentries.argument_extend ~name:"auto_using"
                                                              )])) false)))
                                                              (fun l _ loc ->
                                                              
-# 76 "plugins/ltac/g_auto.mlg"
+# 77 "plugins/ltac/g_auto.mlg"
                                                l 
                                                              ))]);
                                    Tacentries.arg_tag = Some
@@ -159,15 +160,15 @@ let (wit_auto_using, auto_using) = Tacentries.argument_extend ~name:"auto_using"
                                                            (wit_uconstr));
                                    Tacentries.arg_printer = ((fun env sigma -> 
                                                             
-# 74 "plugins/ltac/g_auto.mlg"
+# 75 "plugins/ltac/g_auto.mlg"
                    pr_auto_using_raw env sigma 
                                                             ), (fun env sigma -> 
                                                             
-# 75 "plugins/ltac/g_auto.mlg"
+# 76 "plugins/ltac/g_auto.mlg"
                     pr_auto_using_glob env sigma 
                                                             ), (fun env sigma -> 
                                                             
-# 73 "plugins/ltac/g_auto.mlg"
+# 74 "plugins/ltac/g_auto.mlg"
                pr_auto_using env sigma 
                                                             ));
                                    }
@@ -180,7 +181,7 @@ let () = Tacentries.tactic_extend __coq_plugin_name "trivial" ~level:0
                                                            Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
                                                            Tacentries.TyNil))), 
            (fun lems db ist -> 
-# 84 "plugins/ltac/g_auto.mlg"
+# 85 "plugins/ltac/g_auto.mlg"
       Auto.h_trivial (eval_uconstrs ist lems) db 
            )))]
 
@@ -191,7 +192,7 @@ let () = Tacentries.tactic_extend __coq_plugin_name "info_trivial" ~level:0
                                                                 Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
                                                                 Tacentries.TyNil))), 
            (fun lems db ist -> 
-# 89 "plugins/ltac/g_auto.mlg"
+# 90 "plugins/ltac/g_auto.mlg"
       Auto.h_trivial ~debug:Info (eval_uconstrs ist lems) db 
            )))]
 
@@ -203,7 +204,7 @@ let () = Tacentries.tactic_extend __coq_plugin_name "debug_trivial" ~level:0
                                                          Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
                                                          Tacentries.TyNil)))), 
            (fun lems db ist -> 
-# 94 "plugins/ltac/g_auto.mlg"
+# 95 "plugins/ltac/g_auto.mlg"
       Auto.h_trivial ~debug:Debug (eval_uconstrs ist lems) db 
            )))]
 
@@ -222,7 +223,7 @@ let () = Tacentries.tactic_extend __coq_plugin_name "auto" ~level:0 [(
                                                                     lems db
                                                                     ist -> 
                                                                     
-# 99 "plugins/ltac/g_auto.mlg"
+# 100 "plugins/ltac/g_auto.mlg"
       Auto.h_auto n (eval_uconstrs ist lems) db 
                                                                     )))]
 
@@ -236,7 +237,7 @@ let () = Tacentries.tactic_extend __coq_plugin_name "info_auto" ~level:0
                                                              Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
                                                              Tacentries.TyNil)))), 
            (fun n lems db ist -> 
-# 104 "plugins/ltac/g_auto.mlg"
+# 105 "plugins/ltac/g_auto.mlg"
       Auto.h_auto ~debug:Info n (eval_uconstrs ist lems) db 
            )))]
 
@@ -251,53 +252,26 @@ let () = Tacentries.tactic_extend __coq_plugin_name "debug_auto" ~level:0
                                                          Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
                                                          Tacentries.TyNil))))), 
            (fun n lems db ist -> 
-# 109 "plugins/ltac/g_auto.mlg"
+# 110 "plugins/ltac/g_auto.mlg"
       Auto.h_auto ~debug:Debug n (eval_uconstrs ist lems) db 
            )))]
 
-
-# 114 "plugins/ltac/g_auto.mlg"
- 
-
-let make_depth n = snd (Eauto.make_dimension n None)
-
-(* deprecated in 8.13; the second int_or_var will be removed *)
-let deprecated_eauto_bfs =
-  CWarnings.create
-    ~name:"eauto_bfs" ~category:"deprecated"
-    (fun () -> Pp.str "The syntax [eauto @int_or_var @int_or_var] is deprecated. Use [typeclasses eauto bfs] instead.")
-
-let deprecated_bfs tacname =
-  CWarnings.create
-    ~name:"eauto_bfs" ~category:"deprecated"
-    (fun () -> Pp.str "The syntax [" ++ Pp.str tacname ++ Pp.str "@int_or_var @int_or_var] is deprecated. No replacement yet.")
-
-
-
 let () = Tacentries.tactic_extend __coq_plugin_name "eauto" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("eauto", Tacentries.TyArg (
-                                                         Extend.TUopt (
-                                                         Extend.TUentry (Genarg.get_arg_tag wit_nat_or_var)), 
-                                                         Tacentries.TyArg (
                                                          Extend.TUopt (
                                                          Extend.TUentry (Genarg.get_arg_tag wit_nat_or_var)), 
                                                          Tacentries.TyArg (
                                                          Extend.TUentry (Genarg.get_arg_tag wit_auto_using), 
                                                          Tacentries.TyArg (
                                                          Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
-                                                         Tacentries.TyNil))))), 
-           (fun n p lems db ist -> 
-# 134 "plugins/ltac/g_auto.mlg"
-     
-      ( match n,p with Some _, Some _ -> deprecated_eauto_bfs () | _ -> () );
-      Eauto.gen_eauto (Eauto.make_dimension n p) (eval_uconstrs ist lems) db 
+                                                         Tacentries.TyNil)))), 
+           (fun depth lems db ist -> 
+# 117 "plugins/ltac/g_auto.mlg"
+    Eauto.gen_eauto ?depth (eval_uconstrs ist lems) db 
            )))]
 
 let () = Tacentries.tactic_extend __coq_plugin_name "debug_eauto" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("debug", Tacentries.TyIdent ("eauto", 
-                                                         Tacentries.TyArg (
-                                                         Extend.TUopt (
-                                                         Extend.TUentry (Genarg.get_arg_tag wit_nat_or_var)), 
                                                          Tacentries.TyArg (
                                                          Extend.TUopt (
                                                          Extend.TUentry (Genarg.get_arg_tag wit_nat_or_var)), 
@@ -305,34 +279,27 @@ let () = Tacentries.tactic_extend __coq_plugin_name "debug_eauto" ~level:0
                                                          Extend.TUentry (Genarg.get_arg_tag wit_auto_using), 
                                                          Tacentries.TyArg (
                                                          Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
-                                                         Tacentries.TyNil)))))), 
-           (fun n p lems db ist -> 
-# 142 "plugins/ltac/g_auto.mlg"
-     
-      ( match n,p with Some _, Some _ -> (deprecated_bfs "debug eauto") () | _ -> () );
-      Eauto.gen_eauto ~debug:Debug (Eauto.make_dimension n p) (eval_uconstrs ist lems) db 
+                                                         Tacentries.TyNil))))), 
+           (fun depth lems db ist -> 
+# 122 "plugins/ltac/g_auto.mlg"
+    Eauto.gen_eauto ~debug:Debug ?depth (eval_uconstrs ist lems) db 
            )))]
 
 let () = Tacentries.tactic_extend __coq_plugin_name "info_eauto" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("info_eauto", Tacentries.TyArg (
-                                                              Extend.TUopt (
-                                                              Extend.TUentry (Genarg.get_arg_tag wit_nat_or_var)), 
-                                                              Tacentries.TyArg (
                                                               Extend.TUopt (
                                                               Extend.TUentry (Genarg.get_arg_tag wit_nat_or_var)), 
                                                               Tacentries.TyArg (
                                                               Extend.TUentry (Genarg.get_arg_tag wit_auto_using), 
                                                               Tacentries.TyArg (
                                                               Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
-                                                              Tacentries.TyNil))))), 
-           (fun n p lems db ist -> 
-# 150 "plugins/ltac/g_auto.mlg"
-     
-      ( match n,p with Some _, Some _ -> (deprecated_bfs "info_eauto") () | _ -> () );
-      Eauto.gen_eauto ~debug:Info (Eauto.make_dimension n p) (eval_uconstrs ist lems) db 
+                                                              Tacentries.TyNil)))), 
+           (fun depth lems db ist -> 
+# 127 "plugins/ltac/g_auto.mlg"
+    Eauto.gen_eauto ~debug:Info ?depth (eval_uconstrs ist lems) db 
            )))]
 
-let () = Tacentries.tactic_extend __coq_plugin_name "dfs_eauto" ~level:0 
+let () = Tacentries.tactic_extend __coq_plugin_name "dfs_eauto" ~level:0 ~deprecation:( Deprecation.make ~since:"8.16" ~note:"Use [eauto] instead." () ) 
          [(Tacentries.TyML (Tacentries.TyIdent ("dfs", Tacentries.TyIdent ("eauto", 
                                                        Tacentries.TyArg (
                                                        Extend.TUopt (
@@ -342,24 +309,9 @@ let () = Tacentries.tactic_extend __coq_plugin_name "dfs_eauto" ~level:0
                                                        Tacentries.TyArg (
                                                        Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
                                                        Tacentries.TyNil))))), 
-           (fun p lems db ist -> 
-# 158 "plugins/ltac/g_auto.mlg"
-      Eauto.gen_eauto (Eauto.make_dimension p None) (eval_uconstrs ist lems) db 
-           )))]
-
-let () = Tacentries.tactic_extend __coq_plugin_name "bfs_eauto" ~level:0 ~deprecation:( Deprecation.make ~since:"8.15" ~note:"Use [typeclasses eauto bfs] instead." () ) 
-         [(Tacentries.TyML (Tacentries.TyIdent ("bfs", Tacentries.TyIdent ("eauto", 
-                                                       Tacentries.TyArg (
-                                                       Extend.TUopt (
-                                                       Extend.TUentry (Genarg.get_arg_tag wit_nat_or_var)), 
-                                                       Tacentries.TyArg (
-                                                       Extend.TUentry (Genarg.get_arg_tag wit_auto_using), 
-                                                       Tacentries.TyArg (
-                                                       Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
-                                                       Tacentries.TyNil))))), 
-           (fun p lems db ist -> 
-# 164 "plugins/ltac/g_auto.mlg"
-      Eauto.gen_eauto (true, Eauto.make_depth p) (eval_uconstrs ist lems) db 
+           (fun depth lems db ist -> 
+# 132 "plugins/ltac/g_auto.mlg"
+    Eauto.gen_eauto ?depth (eval_uconstrs ist lems) db 
            )))]
 
 let () = Tacentries.tactic_extend __coq_plugin_name "autounfold" ~level:0 
@@ -369,7 +321,7 @@ let () = Tacentries.tactic_extend __coq_plugin_name "autounfold" ~level:0
                                                               Extend.TUentry (Genarg.get_arg_tag wit_clause_dft_concl), 
                                                               Tacentries.TyNil))), 
            (fun db cl ist -> 
-# 168 "plugins/ltac/g_auto.mlg"
+# 136 "plugins/ltac/g_auto.mlg"
                                                            Eauto.autounfold_tac db cl 
            )))]
 
@@ -381,14 +333,14 @@ let () = Tacentries.tactic_extend __coq_plugin_name "autounfold_one" ~level:0
                                                                   Extend.TUentry (Genarg.get_arg_tag wit_hyp), 
                                                                   Tacentries.TyNil)))), 
            (fun db id ist -> 
-# 173 "plugins/ltac/g_auto.mlg"
+# 141 "plugins/ltac/g_auto.mlg"
       Eauto.autounfold_one (match db with None -> ["core"] | Some x -> "core"::x) (Some (id, Locus.InHyp)) 
            )));
          (Tacentries.TyML (Tacentries.TyIdent ("autounfold_one", Tacentries.TyArg (
                                                                  Extend.TUentry (Genarg.get_arg_tag wit_hintbases), 
                                                                  Tacentries.TyNil)), 
           (fun db ist -> 
-# 175 "plugins/ltac/g_auto.mlg"
+# 143 "plugins/ltac/g_auto.mlg"
       Eauto.autounfold_one (match db with None -> ["core"] | Some x -> "core"::x) None 
           )))]
 
@@ -399,7 +351,7 @@ let () = Tacentries.tactic_extend __coq_plugin_name "unify" ~level:0
                                                          Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                                          Tacentries.TyNil))), 
            (fun x y ist -> 
-# 179 "plugins/ltac/g_auto.mlg"
+# 147 "plugins/ltac/g_auto.mlg"
                                       Tactics.unify x y 
            )));
          (Tacentries.TyML (Tacentries.TyIdent ("unify", Tacentries.TyArg (
@@ -411,7 +363,7 @@ let () = Tacentries.tactic_extend __coq_plugin_name "unify" ~level:0
                                                         Extend.TUentry (Genarg.get_arg_tag wit_preident), 
                                                         Tacentries.TyNil))))), 
           (fun x y base ist -> 
-# 180 "plugins/ltac/g_auto.mlg"
+# 148 "plugins/ltac/g_auto.mlg"
                                                             
     let table = try Some (Hints.searchtable_map base) with Not_found -> None in
     match table with
@@ -425,7 +377,7 @@ let () = Tacentries.tactic_extend __coq_plugin_name "unify" ~level:0
           )))]
 
 
-# 192 "plugins/ltac/g_auto.mlg"
+# 160 "plugins/ltac/g_auto.mlg"
  
 
 let pr_pre_hints_path_atom _ _ _ = Hints.pp_hints_path_atom Libnames.pr_qualid
@@ -442,21 +394,21 @@ let (wit_hints_path_atom, hints_path_atom) = Tacentries.argument_extend ~name:"h
                                                (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                                ((Pcoq.Symbol.token (CLexer.terminal "_"))))
                                                (fun _ loc -> 
-# 208 "plugins/ltac/g_auto.mlg"
+# 176 "plugins/ltac/g_auto.mlg"
                Hints.PathAny 
                                                              ));
                                              (Pcoq.Production.make
                                               (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                               ((Pcoq.Symbol.list1 ((Pcoq.Symbol.nterm global)))))
                                               (fun g loc -> 
-# 207 "plugins/ltac/g_auto.mlg"
+# 175 "plugins/ltac/g_auto.mlg"
                              Hints.PathHints g 
                                                             ))]);
                                              Tacentries.arg_tag = None;
                                              Tacentries.arg_intern = 
                                              Tacentries.ArgInternFun ((fun f ist v -> (ist, f ist v)) (
                                              
-# 203 "plugins/ltac/g_auto.mlg"
+# 171 "plugins/ltac/g_auto.mlg"
                   glob_hints_path_atom 
                                              ));
                                              Tacentries.arg_subst = Tacentries.ArgSubstFun (fun s v -> v);
@@ -464,20 +416,20 @@ let (wit_hints_path_atom, hints_path_atom) = Tacentries.argument_extend ~name:"h
                                              Tacentries.ArgInterpRet;
                                              Tacentries.arg_printer = 
                                              ((fun env sigma -> 
-# 205 "plugins/ltac/g_auto.mlg"
+# 173 "plugins/ltac/g_auto.mlg"
                    pr_pre_hints_path_atom 
                                              ), (fun env sigma -> 
-# 206 "plugins/ltac/g_auto.mlg"
+# 174 "plugins/ltac/g_auto.mlg"
                     pr_hints_path_atom 
                                              ), (fun env sigma -> 
-# 201 "plugins/ltac/g_auto.mlg"
+# 169 "plugins/ltac/g_auto.mlg"
                pr_hints_path_atom 
                                              ));
                                              }
 let _ = (wit_hints_path_atom, hints_path_atom)
 
 
-# 211 "plugins/ltac/g_auto.mlg"
+# 179 "plugins/ltac/g_auto.mlg"
  
 
 let pr_hints_path prc prx pry c = Hints.pp_hints_path c
@@ -497,7 +449,7 @@ let (wit_hints_path, hints_path) = Tacentries.argument_extend ~name:"hints_path"
                                                               (Pcoq.Symbol.self))
                                                               (fun q p loc ->
                                                               
-# 232 "plugins/ltac/g_auto.mlg"
+# 200 "plugins/ltac/g_auto.mlg"
                                        Hints.PathSeq (p, q) 
                                                               ));
                                                             (Pcoq.Production.make
@@ -505,7 +457,7 @@ let (wit_hints_path, hints_path) = Tacentries.argument_extend ~name:"hints_path"
                                                              (Pcoq.Rule.stop)
                                                              ((Pcoq.Symbol.nterm hints_path_atom)))
                                                              (fun a loc -> 
-# 231 "plugins/ltac/g_auto.mlg"
+# 199 "plugins/ltac/g_auto.mlg"
                               Hints.PathAtom a 
                                                                     ));
                                                             (Pcoq.Production.make
@@ -518,7 +470,7 @@ let (wit_hints_path, hints_path) = Tacentries.argument_extend ~name:"hints_path"
                                                              (Pcoq.Symbol.self))
                                                              (fun q _ p
                                                              loc -> 
-# 230 "plugins/ltac/g_auto.mlg"
+# 198 "plugins/ltac/g_auto.mlg"
                                            Hints.PathOr (p, q) 
                                                                     ));
                                                             (Pcoq.Production.make
@@ -526,7 +478,7 @@ let (wit_hints_path, hints_path) = Tacentries.argument_extend ~name:"hints_path"
                                                              (Pcoq.Rule.stop)
                                                              ((Pcoq.Symbol.token (CLexer.terminal "eps"))))
                                                              (fun _ loc -> 
-# 229 "plugins/ltac/g_auto.mlg"
+# 197 "plugins/ltac/g_auto.mlg"
                  Hints.PathEpsilon 
                                                                     ));
                                                             (Pcoq.Production.make
@@ -534,7 +486,7 @@ let (wit_hints_path, hints_path) = Tacentries.argument_extend ~name:"hints_path"
                                                              (Pcoq.Rule.stop)
                                                              ((Pcoq.Symbol.token (CLexer.terminal "emp"))))
                                                              (fun _ loc -> 
-# 228 "plugins/ltac/g_auto.mlg"
+# 196 "plugins/ltac/g_auto.mlg"
                  Hints.PathEmpty 
                                                                     ));
                                                             (Pcoq.Production.make
@@ -545,7 +497,7 @@ let (wit_hints_path, hints_path) = Tacentries.argument_extend ~name:"hints_path"
                                                              ((Pcoq.Symbol.token (CLexer.terminal "*"))))
                                                              (fun _ p loc ->
                                                              
-# 227 "plugins/ltac/g_auto.mlg"
+# 195 "plugins/ltac/g_auto.mlg"
                              Hints.PathStar p 
                                                              ));
                                                             (Pcoq.Production.make
@@ -558,28 +510,28 @@ let (wit_hints_path, hints_path) = Tacentries.argument_extend ~name:"hints_path"
                                                              ((Pcoq.Symbol.token (CLexer.terminal ")"))))
                                                              (fun _ p _
                                                              loc -> 
-# 226 "plugins/ltac/g_auto.mlg"
+# 194 "plugins/ltac/g_auto.mlg"
                                   p 
                                                                     ))]);
                                    Tacentries.arg_tag = None;
                                    Tacentries.arg_intern = Tacentries.ArgInternFun ((fun f ist v -> (ist, f ist v)) (
                                                            
-# 222 "plugins/ltac/g_auto.mlg"
+# 190 "plugins/ltac/g_auto.mlg"
                 glob_hints_path 
                                                            ));
                                    Tacentries.arg_subst = Tacentries.ArgSubstFun (fun s v -> v);
                                    Tacentries.arg_interp = Tacentries.ArgInterpRet;
                                    Tacentries.arg_printer = ((fun env sigma -> 
                                                             
-# 223 "plugins/ltac/g_auto.mlg"
+# 191 "plugins/ltac/g_auto.mlg"
                  pr_pre_hints_path 
                                                             ), (fun env sigma -> 
                                                             
-# 224 "plugins/ltac/g_auto.mlg"
+# 192 "plugins/ltac/g_auto.mlg"
                   pr_hints_path 
                                                             ), (fun env sigma -> 
                                                             
-# 220 "plugins/ltac/g_auto.mlg"
+# 188 "plugins/ltac/g_auto.mlg"
              pr_hints_path 
                                                             ));
                                    }
@@ -591,7 +543,7 @@ let (wit_opthints, opthints) = Tacentries.argument_extend ~name:"opthints"
                                                         [(Pcoq.Production.make
                                                           (Pcoq.Rule.stop)
                                                           (fun loc -> 
-# 239 "plugins/ltac/g_auto.mlg"
+# 207 "plugins/ltac/g_auto.mlg"
            None 
                                                                     ));
                                                         (Pcoq.Production.make
@@ -601,7 +553,7 @@ let (wit_opthints, opthints) = Tacentries.argument_extend ~name:"opthints"
                                                          ((Pcoq.Symbol.token (CLexer.terminal ":"))))
                                                          ((Pcoq.Symbol.list1 ((Pcoq.Symbol.nterm preident)))))
                                                          (fun l _ loc -> 
-# 238 "plugins/ltac/g_auto.mlg"
+# 206 "plugins/ltac/g_auto.mlg"
                                    Some l 
                                                                     ))]);
                                Tacentries.arg_tag = Some
@@ -619,15 +571,15 @@ let (wit_opthints, opthints) = Tacentries.argument_extend ~name:"opthints"
                                                        (wit_preident)));
                                Tacentries.arg_printer = ((fun env sigma -> 
                                                         
-# 237 "plugins/ltac/g_auto.mlg"
+# 205 "plugins/ltac/g_auto.mlg"
                pr_hintbases 
                                                         ), (fun env sigma -> 
                                                         
-# 237 "plugins/ltac/g_auto.mlg"
+# 205 "plugins/ltac/g_auto.mlg"
                pr_hintbases 
                                                         ), (fun env sigma -> 
                                                         
-# 237 "plugins/ltac/g_auto.mlg"
+# 205 "plugins/ltac/g_auto.mlg"
                pr_hintbases 
                                                         ));
                                }
@@ -644,7 +596,7 @@ let () = Vernacextend.vernac_extend ~command:"HintCut" ~classifier:(fun _ -> Ver
                                                                    Vernacextend.TyNil)))))), 
          (let coqpp_body p dbnames
          locality = Vernacextend.vtdefault (fun () -> 
-# 243 "plugins/ltac/g_auto.mlg"
+# 211 "plugins/ltac/g_auto.mlg"
                                                                                                                 
   let entry = Hints.HintsCutEntry (Hints.glob_hints_path p) in
   Hints.add_hints ~locality
