@@ -9,7 +9,7 @@ open Classes
 
 
 
-let __coq_plugin_name = "ltac_plugin"
+let __coq_plugin_name = "coq-core.plugins.ltac"
 let _ = Mltop.add_known_module __coq_plugin_name
 let () = Vernacextend.vernac_extend ~command:"Typeclasses_Unfold_Settings" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Typeclasses", 
@@ -403,7 +403,7 @@ let progress_evars t =
         if eq_constr_mod_evars sigma concl newconcl
         then
           let info = Exninfo.reify () in
-          Tacticals.tclFAIL ~info 0 (Pp.str"No progress made (modulo evars)")
+          Tacticals.tclFAIL ~info (Pp.str"No progress made (modulo evars)")
         else Proofview.tclUNIT ()
       end
     in t <*> check
