@@ -23,7 +23,7 @@ open Ssrcommon
 
 
 
-let __coq_plugin_name = "ssreflect_plugin"
+let __coq_plugin_name = "coq-core.plugins.ssreflect"
 let _ = Mltop.add_known_module __coq_plugin_name
 
 # 38 "plugins/ssr/ssrvernac.mlg"
